/******************************************************************************
*
*       Copyright (C) 2004 Freescale Semiconductor, Inc.
*       All Rights Reserved
*
* Filename:     ATD_Ex.c
* Author:       Nathan Lee - r61614
* Revision:     1.1
*
* Description:	Flashes LED1 and LED2 according to the position on the analog
*				input PTA4, ADCH2.
*
* Notes:        Also serves as an example for the 908AP64 demo board.
*               Created using CodeWarrior 3.1 for HC(S)08.
******************************************************************************/


#include <hidef.h> 			// EnableInterrupts macro
#include <MC68HC908AP64.h>  // Include peripheral declarations
#include "DEMO908AP64.h" 	// Include the demo board declarations


// ---------------------------------------------------------------------------
// Peripheral Initialization Routine
// ---------------------------------------------------------------------------
void PeriphInit(void)
{
   
    DDRB = 0xFF;			// Port B[0..7] equals output
    LED1 = OFF;				// Turn Off LEDs one and two
    LED2 = OFF;			
    
    ADSCR = 0x24;			// A/D Channel 0 is on for PTA4 (POT) input 		
}


// ---------------------------------------------------------------------------
// Main
// ---------------------------------------------------------------------------
void main(void) 
{
	PeriphInit();			// Microcontroller initialization
  	
  	for (;;) {
       		
       	__RESET_WATCHDOG(); // Kicks the dog       		
       		
       	while (ADSCR_COCO == 1) // ATD Finished
       	{
       	
       		// ADRL0 is used in CodeWarrior v3.0
       		// ADR0L is used in CodeWarrior v3.1 
       		if (ADR0L > 0xbf)	// ATD Output => 0xBF
       		{ 
       		  LED1 = ON;
       		  LED2 = ON;
       		}
       			
       		else if (ADR0L > 0x7f)  // ATD Output => 0x7F
       		{
       		  LED1 = OFF;
       		  LED2 = ON;
       		}
       			
       		else if (ADR0L > 0x3f)  // ATD Output => 0x3F
       		{
       		  LED1 = ON;
       		  LED2 = OFF;
       		}
       			
       		else   		// ATD Output < 0x33
       		{
       		  LED1 = OFF;
       		  LED2 = OFF;
       		}
       			
    	}// End While
    			
	}// Loop forever
			
}//end main(void) 
